@@ -40,6 +40,7 @@ from prompt_toolkit.layout.processors import (
     HighlightIncrementalSearchProcessor,
     HighlightMatchingBracketProcessor,
     HighlightSelectionProcessor,
+    TabsProcessor,
 )
 from prompt_toolkit.lexers import SimpleLexer
 from prompt_toolkit.mouse_events import MouseEvent
@@ -371,9 +372,9 @@ def status_bar(python_input: "PythonInput") -> Container:
         else:
             result.extend(
                 [
-                    (TB + " class:key", "[F3]", enter_history),
+                    (TB + " class:status-toolbar.key", "[F3]", enter_history),
                     (TB, " History ", enter_history),
-                    (TB + " class:key", "[F6]", toggle_paste_mode),
+                    (TB + " class:status-toolbar.key", "[F6]", toggle_paste_mode),
                     (TB, " ", toggle_paste_mode),
                 ]
             )
@@ -603,6 +604,7 @@ class PtPythonLayout:
                         ),
                         HighlightSelectionProcessor(),
                         DisplayMultipleCursors(),
+                        TabsProcessor(),
                         # Show matching parentheses, but only while editing.
                         ConditionalProcessor(
                             processor=HighlightMatchingBracketProcessor(chars="[](){}"),
